==> jc-1.4.0.tar.gz: javax/crypto/spec/DESKeySpec.h <==
// public class javax.crypto.spec.DESKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 930a14cb572a1396 javax_crypto_spec_DESKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DESKeySpec_H_
#define _JC_javax_crypto_spec_DESKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DESKeySpec$sub_refs	_jc_javax_crypto_spec_DESKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DESKeySpec$sub_nonrefs	_jc_javax_crypto_spec_DESKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DESKeySpec$refs	_jc_javax_crypto_spec_DESKeySpec$refs;
typedef struct _jc_javax_crypto_spec_DESKeySpec$nonrefs	_jc_javax_crypto_spec_DESKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DESKeySpec$object	_jc_javax_crypto_spec_DESKeySpec$object;

typedef struct _jc_javax_crypto_spec_DESKeySpec$fields_struct	_jc_javax_crypto_spec_DESKeySpec$fields_struct;
typedef const struct _jc_javax_crypto_spec_DESKeySpec$vmethods	_jc_javax_crypto_spec_DESKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DESKeySpec$vtable	_jc_javax_crypto_spec_DESKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_DESKeySpec$vtype	_jc_javax_crypto_spec_DESKeySpec$vtype;

// Class fields structure
struct _jc_javax_crypto_spec_DESKeySpec$fields_struct {
	_jc_object_array	*WEAK__5fKEYS;
	jint	DES__5fKEY__5fLEN;
};
extern _jc_javax_crypto_spec_DESKeySpec$fields_struct _jc_javax_crypto_spec_DESKeySpec$class_fields;

// Constructors
extern void _jc_javax_crypto_spec_DESKeySpec$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_javax_crypto_spec_DESKeySpec$object *, struct _jc_byte_array *);
extern void _jc_javax_crypto_spec_DESKeySpec$method$_init$6b9b44bc28d43597(_jc_env *, struct _jc_javax_crypto_spec_DESKeySpec$object *, struct _jc_byte_array *, jint);

// Virtual methods
extern _jc_byte_array *_jc_javax_crypto_spec_DESKeySpec$method$getKey$6ddd922de8555435(_jc_env *, struct _jc_javax_crypto_spec_DESKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DESKeySpec$method_info$getKey$6ddd922de8555435;

// Static methods
extern void _jc_javax_crypto_spec_DESKeySpec$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jboolean _jc_javax_crypto_spec_DESKeySpec$method$equalsOrComplementEquals$c386998144eb6c34(_jc_env *, struct _jc_byte_array *, jint, struct _jc_byte_array *);
extern jboolean _jc_javax_crypto_spec_DESKeySpec$method$isParityAdjusted$8495d84f2120000f(_jc_env *, struct _jc_byte_array *, jint);
extern jboolean _jc_javax_crypto_spec_DESKeySpec$method$isWeak$c701871aeb1cedec(_jc_env *, struct _jc_byte_array *, jint);

// Virtual methods structure
struct _jc_javax_crypto_spec_DESKeySpec$vmethods {
	_jc_byte_array	*(*getKey$6ddd922de8555435)(_jc_env *, struct _jc_javax_crypto_spec_DESKeySpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_DESKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DESKeySpec$vmethods	javax_crypto_spec_DESKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_DESKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DESKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DESKeySpec$sub_refs {
	_jc_byte_array	*key;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DESKeySpec$refs {
    _jc_javax_crypto_spec_DESKeySpec$sub_refs	javax_crypto_spec_DESKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DESKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DESKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DESKeySpec$sub_nonrefs	javax_crypto_spec_DESKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DESKeySpec$object {
	_jc_javax_crypto_spec_DESKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DESKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_DESKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DESKeySpec$vtype _jc_javax_crypto_spec_DESKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DESKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DESKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_DESKeySpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/DESKeySpec.h <==
// public class javax.crypto.spec.DESKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 930a14cb572a1396 javax_crypto_spec_DESKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DESKeySpec_H_
#define _JC_javax_crypto_spec_DESKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DESKeySpec$sub_refs	_jc_javax_crypto_spec_DESKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DESKeySpec$sub_nonrefs	_jc_javax_crypto_spec_DESKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DESKeySpec$refs	_jc_javax_crypto_spec_DESKeySpec$refs;
typedef struct _jc_javax_crypto_spec_DESKeySpec$nonrefs	_jc_javax_crypto_spec_DESKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DESKeySpec$object	_jc_javax_crypto_spec_DESKeySpec$object;

typedef struct _jc_javax_crypto_spec_DESKeySpec$fields_struct	_jc_javax_crypto_spec_DESKeySpec$fields_struct;
typedef const struct _jc_javax_crypto_spec_DESKeySpec$vmethods	_jc_javax_crypto_spec_DESKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DESKeySpec$vtable	_jc_javax_crypto_spec_DESKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_DESKeySpec$vtype	_jc_javax_crypto_spec_DESKeySpec$vtype;

// Class fields structure
struct _jc_javax_crypto_spec_DESKeySpec$fields_struct {
	_jc_object_array	*WEAK__5fKEYS;
	jint	DES__5fKEY__5fLEN;
};
extern _jc_javax_crypto_spec_DESKeySpec$fields_struct _jc_javax_crypto_spec_DESKeySpec$class_fields;

// Constructors
extern void _jc_javax_crypto_spec_DESKeySpec$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_javax_crypto_spec_DESKeySpec$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_spec_DESKeySpec$method$_init$6b9b44bc28d43597(_jc_env *, struct _jc_javax_crypto_spec_DESKeySpec$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_javax_crypto_spec_DESKeySpec$method$getKey$6ddd922de8555435(_jc_env *, struct _jc_javax_crypto_spec_DESKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DESKeySpec$method_info$getKey$6ddd922de8555435;

// Static methods
extern void _jc_javax_crypto_spec_DESKeySpec$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_crypto_spec_DESKeySpec$method$equalsOrComplementEquals$c386998144eb6c34(_jc_env *, struct _jc_byte_array *, jint, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_crypto_spec_DESKeySpec$method$isParityAdjusted$8495d84f2120000f(_jc_env *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_javax_crypto_spec_DESKeySpec$method$isWeak$c701871aeb1cedec(_jc_env *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_crypto_spec_DESKeySpec$vmethods {
	_jc_byte_array	*(*getKey$6ddd922de8555435)(_jc_env *, struct _jc_javax_crypto_spec_DESKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_DESKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DESKeySpec$vmethods	javax_crypto_spec_DESKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_DESKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DESKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DESKeySpec$sub_refs {
	_jc_byte_array	*key;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DESKeySpec$refs {
    _jc_javax_crypto_spec_DESKeySpec$sub_refs	javax_crypto_spec_DESKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DESKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DESKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DESKeySpec$sub_nonrefs	javax_crypto_spec_DESKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DESKeySpec$object {
	_jc_javax_crypto_spec_DESKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DESKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_DESKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DESKeySpec$vtype _jc_javax_crypto_spec_DESKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DESKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DESKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_DESKeySpec_H_ */
